nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Hashcrypt

Struct Hashcrypt 

pub struct Hashcrypt { /* private fields */ }
Hash-Crypt peripheral

Implementations

Source

impl Hashcrypt

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn ctrl(self) -> Reg<Ctrl, RW>

Control register to enable and operate Hash and Crypto

pub const fn status(self) -> Reg<Status, RW>

Indicates status of Hash peripheral.

pub const fn intenset(self) -> Reg<Intenset, RW>

Write 1 to enable interrupts; reads back with which are set.

pub const fn intenclr(self) -> Reg<Intenclr, RW>

Write 1 to clear interrupts.

pub const fn memctrl(self) -> Reg<Memctrl, RW>

Setup Master to access memory (if available)

pub const fn memaddr(self) -> Reg<Memaddr, RW>

Address to start memory access from (if available).

pub const fn indata(self) -> Reg<Indata, W>

Input of 16 words at a time to load up buffer.

pub const fn alias(self, n: usize) -> Reg<Alias, W>

Aliases to allow writing words in a burst.

pub const fn digest0(self, n: usize) -> Reg<Digest0, R>

Result digest (when status says so): Is 1st 5 words if SHA1 used Is all 8 words if SHA2 used Is all 8 words if crypto or SHA512

pub const fn cryptcfg(self) -> Reg<Cryptcfg, RW>

Crypto settings for AES and Salsa and ChaCha

pub const fn config(self) -> Reg<Config, RW>

Returns the configuration of this block in this chip - indicates what services are available.

pub const fn lock(self) -> Reg<Lock, RW>

Lock register allows locking to the current security level or unlocking by the lock holding level.

pub const fn mask(self, n: usize) -> Reg<Mask, W>

Allows Application to write a random mask for ICB use. Normally only a new one on each system reset (including power up).

pub const fn reload(self, n: usize) -> Reg<Reload, W>

The WO digest-reload registers may be written with a saved Hash digest, to allow continuation from where left off. These registers may only be written if the Reload field in CTRL is 1. If SHA1, only the 1st 5 are used.

pub const fn prng_seed(self) -> Reg<PrngSeed, W>

PRNG random input value used as an entropy source

pub const fn prng_out(self) -> Reg<PrngOut, R>

Provide random number.