pub struct Hashcrypt { /* private fields */ }Expand description
Hash-Crypt peripheral
Implementations
Sourceimpl Hashcrypt
impl Hashcrypt
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn ctrl(self) -> Reg<Ctrl, RW>
pub const fn ctrl(self) -> Reg<Ctrl, RW>
Control register to enable and operate Hash and Crypto
Sourcepub const fn intenset(self) -> Reg<Intenset, RW>
pub const fn intenset(self) -> Reg<Intenset, RW>
Write 1 to enable interrupts; reads back with which are set.
Sourcepub const fn memaddr(self) -> Reg<Memaddr, RW>
pub const fn memaddr(self) -> Reg<Memaddr, RW>
Address to start memory access from (if available).
Sourcepub const fn digest0(self, n: usize) -> Reg<Digest0, R>
pub const fn digest0(self, n: usize) -> Reg<Digest0, R>
Result digest (when status says so): Is 1st 5 words if SHA1 used Is all 8 words if SHA2 used Is all 8 words if crypto or SHA512
Sourcepub const fn config(self) -> Reg<Config, RW>
pub const fn config(self) -> Reg<Config, RW>
Returns the configuration of this block in this chip - indicates what services are available.
Sourcepub const fn lock(self) -> Reg<Lock, RW>
pub const fn lock(self) -> Reg<Lock, RW>
Lock register allows locking to the current security level or unlocking by the lock holding level.
Sourcepub const fn mask(self, n: usize) -> Reg<Mask, W>
pub const fn mask(self, n: usize) -> Reg<Mask, W>
Allows Application to write a random mask for ICB use. Normally only a new one on each system reset (including power up).
Sourcepub const fn reload(self, n: usize) -> Reg<Reload, W>
pub const fn reload(self, n: usize) -> Reg<Reload, W>
The WO digest-reload registers may be written with a saved Hash digest, to allow continuation from where left off. These registers may only be written if the Reload field in CTRL is 1. If SHA1, only the 1st 5 are used.